"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.GalleryLayout = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = require("react-native-reanimated");

var _Layouts = require("./Layouts");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

let GalleryLayout;
exports.GalleryLayout = GalleryLayout;

(function (GalleryLayout) {
  GalleryLayout["Column"] = "column";
  GalleryLayout["ColumnWrap"] = "columnWrap";
  GalleryLayout["Row"] = "row";
  GalleryLayout["RowWrap"] = "rowWrap";
})(GalleryLayout || (exports.GalleryLayout = GalleryLayout = {}));

const getLayout = layout => {
  switch (layout) {
    case GalleryLayout.Column:
      return _Layouts.ColumnLayout;

    case GalleryLayout.ColumnWrap:
      return _Layouts.ColumnWrapLayout;

    case GalleryLayout.Row:
      return _Layouts.RowLayout;

    case GalleryLayout.RowWrap:
      return _Layouts.RowWrapLayout;

    default:
      return _Layouts.RowLayout;
  }
};

const transition = /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.Transition.Change, {
  durationMs: 400,
  interpolation: "easeInOut"
});

/** Component to show items in a Gallery style supporting multiple layouts and animating between them */
const GalleryView = _react.default.forwardRef(({
  layout = GalleryLayout.RowWrap,
  spacing = 5,
  style,
  columnLayoutStyle,
  rowLayoutStyle,
  wrapLayoutStyle,
  itemStyle,
  children
}, ref) => {
  const [currentLayout, setCurrentLayout] = (0, _react.useState)(layout);
  const transitionRef = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, () => ({
    setLayout: newLayout => {
      if (transitionRef.current) {
        transitionRef.current.animateNextTransition();
        setCurrentLayout(newLayout);
      }
    }
  }));
  let providedLayoutStyle = {};
  if (currentLayout === GalleryLayout.Column) providedLayoutStyle = columnLayoutStyle;
  if (currentLayout === GalleryLayout.Row) providedLayoutStyle = rowLayoutStyle;
  if (currentLayout === GalleryLayout.RowWrap) providedLayoutStyle = wrapLayoutStyle;
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.Transitioning.View, {
    style: [styles.container, getLayout(currentLayout).layout.container, style, providedLayoutStyle],
    ref: transitionRef,
    transition: transition
  }, _react.default.Children.map(children, (currChild, index) => {
    if (currChild) {
      const childStyle = [currChild.props.style, getLayout(currentLayout).layout.child, {
        margin: spacing
      }, itemStyle];
      return _react.default.cloneElement(currChild, {
        style: childStyle,
        key: "galleryItem".concat(index)
      });
    } else {
      return null;
    }
  }));
});

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  }
});

var _default = GalleryView;
exports.default = _default;
//# sourceMappingURL=GalleryView.js.map