import React from 'react';
import { StyleProp, ViewStyle } from 'react-native';
export declare enum GalleryLayout {
    Column = "column",
    ColumnWrap = "columnWrap",
    Row = "row",
    RowWrap = "rowWrap"
}
export interface GalleryViewProps {
    /** The layout for the gallery. Defaults to 'row' */
    layout?: GalleryLayout;
    /** The amount of space to have betwen items. Defaults to 5 */
    spacing?: number;
    /** Additional styles or override default styles for each gallery item */
    itemStyle?: StyleProp<any>;
    /** Do not pass this as prop. Use this method to animate the gallery to a new layout. See code example for details */
    setLayout: (newLayout: GalleryLayout) => void;
    /**
     * Additional styles or styles to override default style for all layout modes. This will be overriden by
     * the more specific style props: columnLayoutStyle, rowLayoutStyle, wrapLayoutStyle
     */
    style?: StyleProp<ViewStyle>;
    /** Additional style or override styles when gallery is in column mode */
    columnLayoutStyle?: StyleProp<ViewStyle>;
    /** Additional style or override styles when gallery is in row mode */
    rowLayoutStyle?: StyleProp<ViewStyle>;
    /** Additional style or override styles when gallery is in wrap mode */
    wrapLayoutStyle?: StyleProp<ViewStyle>;
}
/** Component to show items in a Gallery style supporting multiple layouts and animating between them */
declare const GalleryView: React.ForwardRefExoticComponent<Pick<any, string | number | symbol> & React.RefAttributes<GalleryViewProps>>;
export default GalleryView;
